# Jitsi

This guide explains how moeny uses Jitsi Meet as an alternative to Zoom for Video Conferencing. Jitsi Meet is an open-source, secure, and feature-rich video conferencing solution that can be self-hosted.

## Moeny Roadmap - To Add

- [SIP Gateway](#sip-gateway-optional)
- Further Documentation of Deployment
- Waiting Room - Default?

## Overview

Jitsi Meet provides:
- Secure, encrypted video conferencing
- No account required for basic meetings
- Screen sharing capabilities
- Chat functionality
- Recording options
- Mobile apps available

## System Requirements

- Debian 10 (Buster) or newer
- Ubuntu 22.04 (Jammy Jellyfish) or newer
- Root/sudo access
- Required ports:
  - 80 TCP (SSL certificate verification)
  - 443 TCP (HTTPS access)
  - 10000 UDP (Audio/Video)
  - 22 TCP (SSH)
  - 3478 UDP (STUN server)
  - 5349 TCP (Fallback TCP)

## Installation Steps

1. **Update System and Install Dependencies**
   ```bash
   sudo apt update
   sudo apt install apt-transport-https
   sudo apt-add-repository universe
   ```

2. **Add Prosody Repository**
   ```bash
   sudo curl -sL https://prosody.im/files/prosody-debian-packages.key -o /etc/apt/keyrings/prosody-debian-packages.key
   echo "deb [signed-by=/etc/apt/keyrings/prosody-debian-packages.key] http://packages.prosody.im/debian $(lsb_release -sc) main" | sudo tee /etc/apt/sources.list.d/prosody-debian-packages.list
   sudo apt install lua5.2
   ```

3. **Add Jitsi Repository**
   ```bash
   curl -sL https://download.jitsi.org/jitsi-key.gpg.key | sudo sh -c 'gpg --dearmor > /usr/share/keyrings/jitsi-keyring.gpg'
   echo "deb [signed-by=/usr/share/keyrings/jitsi-keyring.gpg] https://download.jitsi.org stable/" | sudo tee /etc/apt/sources.list.d/jitsi-stable.list
   ```

4. **Configure Firewall**
   ```bash
   sudo ufw allow 80/tcp
   sudo ufw allow 443/tcp
   sudo ufw allow 10000/udp
   sudo ufw allow 22/tcp
   sudo ufw allow 3478/udp
   sudo ufw allow 5349/tcp
   sudo ufw enable
   ```

5. **Install Jitsi Meet**
   ```bash
   sudo apt install jitsi-meet
   ```

During installation, you'll be prompted to:
- Choose SSL/TLS certificate option (recommended: Let's Encrypt)
- Enter your hostname (e.g., meet.moeny.com)

## Usage

1. **Starting a Meeting**
   - Visit your Jitsi Meet URL (e.g., https://meet.moeny.ai)
   - Enter a room name
   - Click "Start Meeting"

2. **Joining a Meeting**
   - Share the meeting URL with participants
   - No account required for basic meetings
   - Participants can join via web browser or mobile app

3. **Meeting Features**
   - Click the camera icon to toggle video
   - Click the microphone icon to toggle audio
   - Use the chat icon for text messaging
   - Click the screen icon to share your screen
   - Use the recording icon to record the meeting

## Security Considerations

- All meetings are encrypted by default
- Meeting rooms can be password-protected
- No data is stored on Jitsi servers
- Self-hosted solution ensures data privacy

## Troubleshooting

If you encounter issues:
1. Check firewall settings
2. Verify SSL certificate is valid
3. Check system logs:
   ```bash
   /var/log/jitsi/jvb.log
   /var/log/jitsi/jicofo.log
   /var/log/prosody/prosody.log
   ```

## Additional Features

### SIP Gateway (Optional) 
[Jigasi](https://github.com/jitsi/jigasi)

To enable SIP gateway functionality:
```bash
sudo apt install jigasi
```
This allows regular phone calls to join meetings.

## Support

For additional support or questions, please refer to:
- [Jitsi Documentation](https://jitsi.github.io/handbook/docs/)
- [Jitsi Community Forum](https://community.jitsi.net/)
